import React from 'react';
import { Icon, Modal, Button, Form, message, Input, Spin, Select, Checkbox, InputNumber, DatePicker } from 'antd';
import './contract.less';
import { companySearch } from '../../../tools.js';
import ajax from 'jquery/src/ajax/xhr.js'
import $ from 'jquery/src/ajax';

const ContractAddFrom = Form.create()(React.createClass({
    getContactsList(theUid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/getContacts",
            data: {
                uid: theUid
            },
            success: function (data) {
                let theOption = [];
                if (!data.data) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                        return;
                    };
                };
                for (let item in data.data) {
                    let theData = data.data[item];
                    theOption.push(
                        <Select.Option value={item} key={theData}>{theData}</Select.Option>
                    );
                };
                this.setState({
                    contactsOption: theOption
                });
            }.bind(this),
        });
    },
    getInitialState() {
        return {
            loading: false,
            companyOption: [],
            accelerated: 0,
            acceleratedDate: 0,
            visible: "visible"
        };
    },
    loadData(id) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            cache: false,
            url: globalConfig.context + "/api/admin/contract/detail",
            data: {
                id: id || this.props.data.id
            }
        }).done((data) => {
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            } else {
                this.setState({
                    data: data.data,
                    patentCheck: data.data.patentNum ? true : false,
                    copyrightCheck: data.data.copyrightNum ? true : false,
                    highTechCheck: data.data.cognizanceYear ? true : false,
                    techProjectCheck: data.data.techProjectNum ? true : false,
                });
            };
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    componentWillMount() {
        let d = new Date(), _me = this, theArr = [];
        d = d.getFullYear() - 1;
        for (let i = d; i < d + 20; i++) {
            theArr.push(
                <Select.Option value={i.toString()} key={i}>{i}</Select.Option>
            )
        };
        this.state.yearOption = theArr;
        if (this.props.data && this.props.data.uid && this.props.data.id) {
            this.getContactsList(this.props.data.uid);
            this.loadData(this.props.data.id);
        } else {
            this.state.data = {};
            this.state.patentCheck = false;
            this.state.copyrightCheck = false;
            this.state.highTechCheck = false;
            this.state.techProjectCheck = false;
        };
    },
    componentWillReceiveProps(nextProps) {
        if (!this.props.visible && nextProps.visible) {
            if (nextProps.data && nextProps.data.uid && nextProps.data.id) {
                this.getContactsList(nextProps.data.uid);
                this.loadData(nextProps.data.id);
            } else {
                this.state.data = {};
                this.state.patentCheck = false;
                this.state.copyrightCheck = false;
                this.state.highTechCheck = false;
                this.state.techProjectCheck = false;
            };
            this.props.form.resetFields();
        };
    },
    handleSave(e) {
        e.preventDefault();
        this.props.form.validateFields((err, values) => {
            if (!err) {
                if (!(this.state.data.uid || values.uid) || !values.contacts) {
                    message.warning('请选择一个公司和联系人!');
                    return;
                }
                if (!values.patentNum && !values.copyrightNum && !values.cognizanceYear && !values.techProjectNum) {
                    message.warning('请至少选择一个申报项目!');
                    return;
                };
                this.props.spinState(true);
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + "/api/admin/contract/apply",
                    data: {
                        "uid": this.state.data.uid || values.uid,
                        "id": this.state.data.id,
                        "contacts": values.contacts, //联系人
                        "type": values.type, //合同类型
                        "depict": values.depict, // "合同描述",
                        "patentNum": this.state.patentCheck ? values.patentNum : 0,
                        "copyrightNum": this.state.copyrightCheck ? values.copyrightNum : 0,
                        "cognizanceYear": this.state.highTechCheck ? values.cognizanceYear : undefined,
                        "techProjectNum": this.state.techProjectCheck ? values.techProjectNum : 0,
                        "previousFee": values.previousFee,
                        "comment": values.comment //"备注"
                    }
                }).done(function (data) {
                    if (!data.error.length) {
                        message.success('保存成功！');
                        this.props.okClick();
                        this.props.closeModal();
                        this.props.form.resetFields();
                    } else {
                        message.warning(data.error[0].message);
                    }
                }.bind(this)).always(function () {
                    this.props.spinState(false);
                }.bind(this));
            }
        });
    },
    handleSubmit() {
        this.props.form.validateFields((err, values) => {
            if (!err) {
                if (!values.principals || !values.recordTime) {
                    message.warning('请填写审核信息!');
                    return;
                };
                this.props.spinState(true);
                $.ajax({
                    method: "POST",
                    dataType: "json",
                    crossDomain: false,
                    url: globalConfig.context + "/api/admin/contract/submit",
                    data: {
                        "uid": this.state.data.uid || values.uid,
                        "id": this.state.data.id,
                        "contacts": values.contacts, //联系人
                        "type": values.type, //合同类型
                        "depict": values.depict, // "合同描述",
                        "patentNum": this.state.patentCheck ? values.patentNum : 0,
                        "copyrightNum": this.state.copyrightCheck ? values.copyrightNum : 0,
                        "cognizanceYear": this.state.highTechCheck ? values.cognizanceYear : undefined,
                        "techProjectNum": this.state.techProjectCheck ? values.techProjectNum : 0,
                        "principals": values.principals,
                        "previousFee": values.previousFee,
                        "signDateFormattedDate": values.recordTime ? values.recordTime.format("YYYY-MM-DD HH:mm:ss") : undefined,
                        "comment": values.comment //"备注"
                    }
                }).done(function (data) {
                    if (!data.error.length) {
                        message.success('提交成功！');
                        this.props.okClick();
                        this.props.closeModal();
                        this.props.form.resetFields();
                    } else {
                        message.warning(data.error[0].message);
                    }
                }.bind(this)).always(function () {
                    this.props.spinState(false);
                }.bind(this));
            }
        });
    },
    render() {
        const FormItem = Form.Item;
        const { getFieldDecorator } = this.props.form;
        const theData = this.state.data || {};
        const formItemLayout = {
            labelCol: { span: 6 },
            wrapperCol: { span: 14 },
        };
        const _me = this;
        return (
            <Form horizontal onSubmit={this.handleSave} id="CopyrightDesc-form">
                <div className="clearfix">
                    {theData.uid ? <FormItem className="half-item"
                        {...formItemLayout}
                        label="公司名称" >
                        <span>{theData.unitName}</span>
                    </FormItem> : <FormItem className="half-item"
                        {...formItemLayout}
                        label="公司名称" >
                            {getFieldDecorator('uid')(
                                theData.uid ? <span>{theData.unitName}</span> : <Select
                                    placeholder="请选择公司"
                                    notFoundContent="未找到公司"
                                    style={{ width: 260 }}
                                    showSearch
                                    filterOption={companySearch}
                                    onSelect={(e, n) => { this.getContactsList(e); }}>
                                    {this.props.companyOption}
                                </Select>
                            )}
                        </FormItem>
                    }
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="联系人" >
                        {getFieldDecorator('contacts', {
                            initialValue: theData.contacts
                        })(
                            <Select placeholder="请选择联系人"
                                style={{ width: 260 }}
                                notFoundContent="未获取到联系人列表">
                                {this.state.contactsOption}
                            </Select>
                            )}
                    </FormItem>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="合同类型" >
                        {getFieldDecorator('type', {
                            initialValue: theData.type
                        })(
                            <Select placeholder="请选择合同类型"
                                style={{ width: 260 }}>
                                {this.props.typeOption}
                            </Select>
                            )}
                    </FormItem>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="前期费用" >
                        {getFieldDecorator('previousFee', {
                            initialValue: theData.previousFee
                        })(
                            <InputNumber min={0} max={999999} step={0.01} style={{ width: '80px', marginRight: '20px' }} />
                            )}
                        <span>万元</span>
                    </FormItem>
                </div>
                <FormItem
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 19 }}
                    label="合同描述" >
                    {getFieldDecorator('depict', {
                        initialValue: theData.depict
                    })(
                        <Input type="textarea"
                            placeholder="多行输入"
                            rows={4} />
                        )}
                </FormItem>
                <div className="clearfix">
                    <span style={{ float: "left", lineHeight: '32px', marginLeft: '50px' }}>
                        <Checkbox checked={this.state.highTechCheck} onChange={(e) => {
                            this.setState({ highTechCheck: e.target.checked });
                        }}></Checkbox>
                    </span>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label={"高企申请"} >
                        {getFieldDecorator('cognizanceYear', {
                            initialValue: theData.cognizanceYear ? String(theData.cognizanceYear) : null
                        })(
                            <Select placeholder="请选择年份"
                                style={{ width: 120 }}
                                onSelect={(e, n) => { this.setState({ year: e }); }}>
                                {this.state.yearOption}
                            </Select>
                            )}
                    </FormItem>
                </div>
                <div className="clearfix">
                    <span style={{ float: "left", lineHeight: '32px', marginLeft: '50px' }}>
                        <Checkbox checked={this.state.patentCheck} onChange={(e) => {
                            this.setState({ patentCheck: e.target.checked });
                        }}></Checkbox>
                    </span>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label={"专利申请"} >
                        {getFieldDecorator('patentNum', {
                            initialValue: theData.patentNum
                        })(
                            <InputNumber />
                            )}
                    </FormItem>
                </div>
                <div className="clearfix">
                    <span style={{ float: "left", lineHeight: '32px', marginLeft: '50px' }}>
                        <Checkbox checked={this.state.copyrightCheck} onChange={(e) => {
                            this.setState({ copyrightCheck: e.target.checked });
                        }}></Checkbox>
                    </span>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label={"软著申请"} >
                        {getFieldDecorator('copyrightNum', {
                            initialValue: theData.copyrightNum
                        })(
                            <InputNumber />
                            )}
                    </FormItem>
                </div>
                <div className="clearfix">
                    <span style={{ float: "left", lineHeight: '32px', marginLeft: '50px' }}>
                        <Checkbox checked={this.state.techProjectCheck} onChange={(e) => {
                            this.setState({ techProjectCheck: e.target.checked });
                        }}></Checkbox>
                    </span>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label={"科技项目申请"} >
                        {getFieldDecorator('techProjectNum', {
                            initialValue: theData.techProjectNum
                        })(
                            <InputNumber />
                            )}
                    </FormItem>
                </div>
                <div className="clearfix">
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label={"审核人"} >
                        {getFieldDecorator('principals')(
                            <Select
                                placeholder="请选择审核人"
                                notFoundContent="未找到"
                                style={{ width: 260 }}
                                showSearch
                                multiple
                                filterOption={companySearch} >
                                {this.props.authorOption}
                            </Select>
                        )}
                    </FormItem>
                    <FormItem className="half-item"
                        {...formItemLayout}
                        label="处理时间"
                    >
                        {getFieldDecorator('recordTime')(
                            <DatePicker />
                        )}
                    </FormItem>
                </div>
                <FormItem
                    labelCol={{ span: 3 }}
                    wrapperCol={{ span: 19 }}
                    label="备注" >
                    {getFieldDecorator('comment', {
                        initialValue: theData.comment
                    })(
                        <Input type="textarea"
                            placeholder="多行输入"
                            rows={2} />
                        )}
                </FormItem>
                <p style={{ color: '#ea0862', paddingLeft: '40px', marginBottom: '20px' }}>合同提交以后无法修改,请确认提交内容的正确性!</p>
                <FormItem style={{ paddingLeft: '40px' }}>
                    <Button className="set-submit" type="primary" htmlType="submit">保存草稿</Button>
                    <Button onClick={this.handleSubmit} type="ghost" style={{ marginLeft: '20px' }}>提交</Button>
                    <Button type="ghost" style={{ marginLeft: '20px' }} onClick={this.props.closeModal}>取消</Button>
                </FormItem>
            </Form >
        );
    },
}));



const ContractAdd = React.createClass({
    getInitialState() {
        return {
            visible: false,
            loading: false
        };
    },
    showModal() {
        this.setState({
            visible: true,
            data: {}
        });
    },
    handleCancel(e) {
        this.setState({
            visible: false,
        });
        this.props.closeAdd(false);
    },
    componentWillReceiveProps(nextProps) {
        if (nextProps.showAdd && nextProps.data) {
            this.state.data = nextProps.data;
        };
        this.state.visible = nextProps.showAdd;
    },
    spinChange(e) {
        this.setState({
            loading: e
        });
    },
    render() {
        return (
            <div className="patent-addNew">
                <Button className="patent-addNew" type="primary" onClick={this.showModal}>申请合同<Icon type="plus" /></Button>
                <Modal maskClosable={false} title="合同详情"
                    visible={this.state.visible}
                    onCancel={this.handleCancel}
                    width='800px'
                    footer='' >
                    <Spin spinning={this.state.loading} className='spin-box'>
                        <ContractAddFrom
                            spinState={this.spinChange}
                            closeModal={this.handleCancel}
                            visible={this.state.visible}
                            data={this.state.data}
                            okClick={() => { this.props.closeAdd(false, true) }}
                            companyOption={this.props.companyOption}
                            authorOption={this.props.authorOption}
                            typeOption={this.props.typeOption} />
                    </Spin>
                </Modal>
            </div>
        );
    },
});
export default ContractAdd;