import React from 'react';
import { Icon, Button, Spin, message, Table } from 'antd';
import {
    getSearchUrl, getScaleState, getCompanyType, getIndustryType, getCatagory, getIntellectualObtainWay,
    getTechnicalSource
} from '../../../tools.js';
import { getProvince } from '../../../NewDicProvinceList';
import { getTechField } from '../../../DicTechFieldList';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import './highTechFoster.less';


const highTechInfo = React.createClass({
    getInitialState() {
        return {
            loading: false,
            year: new Date().getFullYear() - 1,
            field: [],
            registerType: [],
            netAssetRate: 0,
            salesRevenueRate: 0,
            humanColumns: [
                {
                    title: '公民类型',
                    dataIndex: 'type',
                    key: 'type',
                    width: '130px',
                    render: (text, record, index) => {
                        if (text == '0') {
                            return '中国公民';
                        } else if (text == '1') {
                            return '外籍公民';
                        };
                    }
                }, {
                    title: '姓名',
                    dataIndex: 'name',
                    key: 'name'
                }, {
                    title: '身份证(护照)号',
                    dataIndex: 'idNumber',
                    key: 'idNumber'
                }, {
                    title: '投资额（万元）',
                    dataIndex: 'investment',
                    key: 'investment'
                }
            ],
            legalColumns: [
                {
                    title: '法人类型',
                    dataIndex: 'type',
                    key: 'type',
                    width: '130px',
                    render: (text, record, index) => {
                        if (text == '0') {
                            return '中国企业法人';
                        } else if (text == '1') {
                            return '外籍企业法人';
                        };
                    }
                }, {
                    title: '名称',
                    dataIndex: 'name',
                    key: 'name'
                }, {
                    title: '组织机构代码或统一社会信用代码',
                    dataIndex: 'orgCode',
                    key: 'orgCode'
                }, {
                    title: '投资额（万元）',
                    dataIndex: 'investment',
                    key: 'investment'
                }
            ],
            moneyColumns: [
                {
                    title: '',
                    dataIndex: 'year',
                    key: 'year',
                }, {
                    title: '净资产',
                    dataIndex: 'netAsset',
                    key: 'netAsset',
                }, {
                    title: '销售收入',
                    dataIndex: 'salesRevenue',
                    key: 'salesRevenue',
                }, {
                    title: '利润总额',
                    dataIndex: 'grossProfit',
                    key: 'grossProfit',
                }
            ],
            intellectualColumns: [
                {
                    title: '知识产权编号',
                    dataIndex: 'intellectualPropertyNumber',
                    key: 'intellectualPropertyNumber',
                }, {
                    title: '知识产权名称',
                    dataIndex: 'intellectualPropertyName',
                    key: 'intellectualPropertyName',
                }, {
                    title: '类型',
                    dataIndex: 'catagory',
                    key: 'catagory',
                    render: (text) => {
                        return getCatagory(text);
                    }
                }, {
                    title: '授权日期',
                    dataIndex: 'authorizationDateFormattedDate',
                    key: 'authorizationDateFormattedDate',
                }, {
                    title: '授权号',
                    dataIndex: 'authorizationNumber',
                    key: 'authorizationNumber',
                }, {
                    title: '获取方式',
                    dataIndex: 'obtainWay',
                    key: 'obtainWay',
                    render: (text) => {
                        return getIntellectualObtainWay(text);
                    }
                }
            ],
            activityCostColumns: [
                {
                    title: '研发活动编号',
                    dataIndex: 'activityNumber',
                    key: 'activityNumber'
                }, {
                    title: '内部研究开发费用',
                    dataIndex: 'internalAllCost',
                    key: 'internalAllCost'
                }, {
                    title: '人员人工费用',
                    dataIndex: 'internalLaborCost',
                    key: 'internalLaborCost'
                }, {
                    title: '直接投入费用',
                    dataIndex: 'internalDirectCost',
                    key: 'internalDirectCost'
                }, {
                    title: '折旧费用与长期待摊费用',
                    dataIndex: 'internalDepreciationCost',
                    key: 'internalDepreciationCost'
                }, {
                    title: '设计费用',
                    dataIndex: 'internalDesignCost',
                    key: 'internalDesignCost'
                }, {
                    title: '装备调试费用与试验费用',
                    dataIndex: 'internalEquipmentCost',
                    key: 'internalEquipmentCost'
                }, {
                    title: '其他费用',
                    dataIndex: 'internalOtherCost',
                    key: 'internalOtherCost'
                }, {
                    title: '委托外部研究开发费用',
                    dataIndex: 'externalTotalCost',
                    key: 'externalTotalCost'
                }, {
                    title: '境内外部研发费用',
                    dataIndex: 'externalAbroadCost',
                    key: 'externalAbroadCost'
                }, {
                    title: '研发费用合计',
                    dataIndex: 'allCost',
                    key: 'allCost'
                }
            ],
            standardColumns: [
                {
                    title: '编号',
                    dataIndex: 'key',
                    key: 'key'
                }, {
                    title: '标准名称',
                    dataIndex: 'standardName',
                    key: 'standardName'
                }, {
                    title: '标准级别',
                    dataIndex: 'standardLevel',
                    key: 'standardLevel',
                    render: text => {
                        switch (text) {
                            case 0:
                                return "国家";
                            case 1:
                                return "行业";
                        };
                    }
                }, {
                    title: '标准编号',
                    dataIndex: 'standardNumber',
                    key: 'standardNumber'
                }, {
                    title: '参与方式',
                    dataIndex: 'participateWay',
                    key: 'participateWay',
                    render: text => {
                        switch (text) {
                            case 0:
                                return "主持";
                            case 1:
                                return "参与";
                        };
                    }
                }
            ]
        };
    },
    //基础资料
    loadInfoData(uid) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/basic/info",
            data: {
                uid: uid
            }
        }).done(function (data) {
            let thisdata = data.data;
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            } else {
                this.setState({
                    id: thisdata.id,
                    uid: thisdata.uid,
                    hid: thisdata.hid,
                    unitName: thisdata.unitName,
                    postalAddress: thisdata.postalAddress,
                    postcode: thisdata.postcode,
                    contacts: thisdata.contacts,
                    contactMobile: thisdata.contactMobile,
                    contactsFixedTel: thisdata.contactsFixedTel,
                    firstContacts: thisdata.firstContacts,
                    firstMobile: thisdata.firstMobile,
                    contactsFax: thisdata.contactsFax,
                    legalPersonTel: thisdata.legalPersonTel,
                    legalPersonFax: thisdata.legalPersonFax,
                    legalPersonEmail: thisdata.legalPersonEmail,
                    registeredCapital: thisdata.registeredCapital,
                    registrationTime: thisdata.registrationTime,
                    legalPerson: thisdata.legalPerson,
                    legalPersonIdCard: thisdata.legalPersonIdCard,
                    orgCode: thisdata.orgCode,
                    ratepayCode: thisdata.ratepayCode,
                    industry: thisdata.industry,
                    enterpriseScale: thisdata.enterpriseScale,
                    foreignInvestment: thisdata.foreignInvestment,
                    taxAuthority: thisdata.taxAuthority,
                    ratepayMethod: thisdata.ratepayMethod,
                    listed: thisdata.listed,
                    listedDate: thisdata.listedDate,
                    listedType: thisdata.listedType,
                    stockCode: thisdata.stockCode,
                    highTechZone: thisdata.highTechZone,
                    highTechName: thisdata.highTechName,
                    riskInvestment: thisdata.riskInvestment,
                    businessScope: thisdata.businessScope,
                    firmTotal: thisdata.firmTotal,
                    techTotal: thisdata.techTotal,
                    listedDateFormattedDate: thisdata.listedDateFormattedDate,
                    registrationTimeFormattedDate: thisdata.registrationTimeFormattedDate,
                    address: getProvince(thisdata.licenceProvince, thisdata.licenceCity, thisdata.licenceArea),
                    field: thisdata.field ? thisdata.field.split(',') : [],
                    registerType: thisdata.registerType ? thisdata.registerType.split(',') : []
                });
            };
        }.bind(this)).always(function () {
            this.setState({
                loading: false
            });
            this.loadHighTechList(this.state.uid);
        }.bind(this));
    },
    loadHumanData(uid) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/basic/listNature",
            data: {
                uid: uid
            }
        }).done(function (data) {
            let theTableData = [];
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
                return;
            };
            data.data.map(function (item) {
                theTableData.push({
                    id: item.id,
                    uid: item.uid,
                    type: item.type,
                    name: item.name,
                    idNumber: item.idNumber,
                    investment: item.investment
                });
            });
            this.setState({
                humanTableData: theTableData
            });
        }.bind(this)).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    loadLegalData(uid) {
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/basic/listLegalPerson",
            data: {
                uid: uid
            }
        }).done(function (data) {
            let theTableData = [];
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
                return;
            };
            data.data.map(function (item) {
                theTableData.push({
                    id: item.id,
                    uid: item.uid,
                    type: item.type,
                    name: item.name,
                    orgCode: item.idNumber,
                    investment: item.investment
                });
            });
            this.setState({
                legalTableData: theTableData
            });
        }.bind(this)).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    //申请书
    //第一
    loadHighTechList(uid) {
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/listCognizance",
            data: {
                uid: uid
            },
            success: function (data) {
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    let _me = this;
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        if (thisdata.year == this.state.year) {
                            _me.loadHighTechApply(uid, thisdata.cid, this.state.year)
                        }
                    };
                };
            }.bind(this),
        }).always(function () {
            this.loadIntellectualData(uid);
        }.bind(this));
    },
    loadHighTechApply(uid, cid, year) {
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/cognizanceDetail",
            data: {
                uid: uid,
                cid: cid,
                year: year + 1
            }
        }).done(function (data) {
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            } else {
                this.state.moneyTable = [
                    {
                        key: 1,
                        year: '前一年',
                        netAsset: data.data.netAsset1,
                        salesRevenue: data.data.salesRevenue1,
                        grossProfit: data.data.grossProfit1
                    }, {
                        key: 2,
                        year: '前二年',
                        netAsset: data.data.netAsset2,
                        salesRevenue: data.data.salesRevenue2,
                        grossProfit: data.data.grossProfit2
                    }, {
                        key: 3,
                        year: '前三年',
                        netAsset: data.data.netAsset3,
                        salesRevenue: data.data.salesRevenue3,
                        grossProfit: data.data.grossProfit3
                    }
                ];
                if (data.data.netAsset2 == 0) {
                    this.state.netAssetRate = 0;
                } else if (data.data.netAsset3 == 0) {
                    this.state.netAssetRate = (data.data.netAsset1 / data.data.netAsset2) - 1;
                } else {
                    this.state.netAssetRate = 1 / 2 * (data.data.netAsset2 / data.data.netAsset3 + data.data.netAsset1 / data.data.netAsset2) - 1;
                };
                if (this.state.netAssetRate < 0 || isNaN(this.state.netAssetRate)) {
                    this.state.netAssetRate = 0
                };
                if (data.data.salesRevenue2 == 0) {
                    this.state.salesRevenueRate = 0;
                } else if (data.data.salesRevenue3 == 0) {
                    this.state.salesRevenueRate = (data.data.salesRevenue1 / data.data.salesRevenue2) - 1;
                } else {
                    this.state.salesRevenueRate = 1 / 2 * (data.data.salesRevenue2 / data.data.salesRevenue3 + data.data.salesRevenue1 / data.data.salesRevenue2) - 1;
                };
                if (this.state.salesRevenueRate < 0 || isNaN(this.state.salesRevenueRate)) {
                    this.state.salesRevenueRate = 0
                };
                this.setState({
                    firstCatagory: data.data.firstCatagory,
                    secondCatagory: data.data.secondCatagory,
                    firmTotal: data.data.firmTotal,
                    techTotal: data.data.techTotal,
                    researchCost: data.data.researchCost,
                    territory: data.data.territory,
                    basicResearchCost: data.data.basicResearchCost,
                    totalRevenue: data.data.totalRevenue,
                    lastYearRevenue: data.data.lastYearRevenue,
                    accident: data.data.accident
                });
            };
        }.bind(this));
    },
    //第二
    loadIntellectualData(uid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/summary/intellectualProperty",
            data: {
                uid: uid
            }
        }).done(function (data) {
            let theTableData = [];
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            } else {
                this.setState({
                    inventionPatent: data.data.inventionPatent, //发明专利数
                    defensePatent: data.data.defensePatent,   //国防专利数
                    nationalCrop: data.data.nationalCrop,    //国家级农作物品种数
                    newPlantCariety: data.data.newPlantCariety, //植物新品种数
                    nationalDrug: data.data.nationalDrug,    //国家新药数
                    chineseMedicine: data.data.chineseMedicine, //国家一级中药保护品种数
                    utilityPatent: data.data.utilityPatent,   //实用新型专利数
                    circuitDesign: data.data.circuitDesign,   //集成电路布图设计专有权数
                    exteriorPatent: data.data.exteriorPatent,  //外观设计专利数
                    softwareWorks: data.data.softwareWorks    //软件著作权数
                });
            };
        }.bind(this)).always(function () {
            this.loadIntellectualListData(uid);
        }.bind(this));
    },
    loadIntellectualListData(uid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/summary/intellectualPropertyList",
            data: {
                uid: uid
            }
        }).done(function (data) {
            let theTableData = [];
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            } else {
                data.data.map(function (item) {
                    theTableData.push({
                        id: item.id,
                        uid: item.uid,
                        pid: item.pid,
                        intellectualPropertyNumber: item.intellectualPropertyNumber,
                        intellectualPropertyName: item.intellectualPropertyName,
                        sortNumber: item.sortNumber,
                        catagory: item.catagory,
                        obtainWay: item.obtainWay,
                        authorizationNumber: item.authorizationNumber,
                        authorizationDate: item.authorizationDate,
                        propertyRightUrl: item.propertyRightUrl,
                        type: item.type,
                        authorizationDateFormattedDate: item.authorizationDateFormattedDate,
                        propertyRightDownloadFileName: item.propertyRightDownloadFileName
                    });
                });
            };
            this.setState({
                intellectualTableData: theTableData
            });
        }.bind(this)).always(function () {
            this.loadHRData(uid);
        }.bind(this));
    },
    //第三
    loadHRData(uid) {
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/orgHumanResource",
            data: {
                uid: uid,
                year: this.state.year
            }
        }).done(function (data) {
            if (!data.data || !data.data.list) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            } else {
                let thisdata = data.data.list[0] || {};
                this.setState({
                    aboveFifty: thisdata.aboveFifty,
                    belowThirty: thisdata.belowThirty,
                    college: thisdata.college,
                    doctor: thisdata.doctor,
                    firmAbroad: thisdata.firmAbroad,
                    firmCore: thisdata.firmCore,
                    firmForeign: thisdata.firmForeign,
                    firmInService: thisdata.firmInService,
                    firmPartTime: thisdata.firmPartTime,
                    firmTemporary: thisdata.firmTemporary,
                    firmTotal: thisdata.firmTotal,
                    fortyoneToFifty: thisdata.fortyoneToFifty,
                    intermediateTitle: thisdata.intermediateTitle,
                    juniorTitle: thisdata.juniorTitle,
                    master: thisdata.master,
                    seniorMechanic: thisdata.seniorMechanic,
                    seniorTitle: thisdata.seniorTitle,
                    techAbroad: thisdata.techAbroad,
                    techCore: thisdata.techCore,
                    techForeign: thisdata.techForeign,
                    techInService: thisdata.techInService,
                    techPartTime: thisdata.techPartTime,
                    techTemporary: thisdata.techTemporary,
                    techTotal: thisdata.techTotal,
                    thirtyoneToThirtyfour: thisdata.thirtyoneToThirtyfour,
                    undergraduate: thisdata.undergraduate,
                });
            };
        }.bind(this)).always(function () {
            this.loadActivityData(uid);
        }.bind(this));
    },
    //第四
    loadActivityData(uid) {
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/summary/activity",
            data: {
                uid: uid
            }
        }).done(function (data) {
            let theArr = [];
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                }
            } else {
                data.data.map(function (item) {
                    theArr.push(
                        <li key={item.id}>
                            <p style={{ marginBottom: '10px', fontSize: '14px' }}><span>活动编号 </span> {item.activityNumber}</p>
                            <div className="clearfix">
                                <div className="half-item">
                                    <span className="item-title">研发活动名称</span>
                                    <span>{item.activityName}</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">起止时间</span>
                                    <span>{item.startDateFormattedDate + ' -- ' + item.endDateFormattedDate}</span>
                                </div>
                            </div>
                            <div className="all-item">
                                <span className="item-title">技术领域</span>
                                <span>{getTechField(Number(item.technicalField1), item.technicalField2 ? Number(item.technicalField2) : null, item.technicalField3 ? Number(item.technicalField3) : null)}</span>
                            </div>
                            <div className="clearfix">
                                <div className="half-item">
                                    <span className="item-title">技术来源</span>
                                    <span>{getTechnicalSource(item.technicalSource)}</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">知识产权编号</span>
                                    <span>{item.intellectualPropertyNumber}</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">研发费用总预算</span>
                                    <span>{item.budget}</span>
                                    <span>万元</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">研发费用近三年总支出</span>
                                    <span>{item.firstYearExpenditure + item.secondYearExpenditure + item.thirdYearExpenditure}</span>
                                    <span>万元</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">其中 第一年</span>
                                    <span>{item.firstYearExpenditure}</span>
                                    <span>万元</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">第二年</span>
                                    <span>{item.secondYearExpenditure}</span>
                                    <span>万元</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">第三年</span>
                                    <span>{item.thirdYearExpenditure}</span>
                                    <span>万元</span>
                                </div>
                            </div>
                            <div className="all-item">
                                <span className="item-title">目的及组织实施方式</span>
                                <span>{item.implement}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">核心技术及创新点</span>
                                <span>{item.technologyInnovation}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">取得的阶段性成果</span>
                                <span>{item.achievement}</span>
                            </div>
                        </li>
                    )
                });
            };
            this.setState({
                activityData: theArr
            });
        }.bind(this)).always(function () {
            this.loadActivityCostData(uid);
        }.bind(this));
    },
    //第五
    loadActivityCostData(uid) {
        $.when($.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/activityCostList",
            data: {
                uid: uid,
                year: this.state.year - 2
            }
        }), $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/activityCostList",
            data: {
                uid: uid,
                year: this.state.year - 1
            }
        }), $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/activityCostList",
            data: {
                uid: uid,
                year: this.state.year
            }
        })).done(function (data1, data2, data3) {
            let firstArr = [];
            let secondArr = [];
            let thirdArr = [];
            if (!data1[0].data && !data1[0].data.list) {
                if (data1[0].error && data1[0].error.length) {
                    message.warning(data1[0].error[0].message);
                };
            } else {
                data1[0].data.list.map(function (item) {
                    firstArr.push({
                        id: item.id,
                        uid: item.uid,
                        aid: item.aid,
                        activityNumber: item.activityNumber,
                        year: item.year,
                        startDate: item.startDate,
                        endDate: item.endDate,

                        internalAllCost:
                        item.internalLaborCost + item.internalDirectCost + item.internalDepreciationCost +
                        item.internalAmortizationCost + item.internalAmortizationCost + item.internalDesignCost +
                        item.internalEquipmentCost + item.internalOtherCost,

                        internalLaborCost: item.internalLaborCost,
                        internalDirectCost: item.internalDirectCost,
                        internalDepreciationCost: item.internalDepreciationCost,
                        internalAmortizationCost: item.internalAmortizationCost,
                        internalDesignCost: item.internalDesignCost,
                        internalEquipmentCost: item.internalEquipmentCost,
                        internalOtherCost: item.internalOtherCost,

                        externalTotalCost: item.externalTotalCost,
                        externalAbroadCost: item.externalAbroadCost,

                        allCost:
                        item.internalLaborCost + item.internalDirectCost + item.internalDepreciationCost +
                        item.internalAmortizationCost + item.internalAmortizationCost + item.internalDesignCost +
                        item.internalEquipmentCost + item.internalOtherCost + item.externalTotalCost,

                        enterpriseFiller: item.enterpriseFiller,
                        signDate: item.signDate,
                        signDateFormattedDate: item.signDateFormattedDate,

                        sortNumber: item.sortNumber,

                        startDateFormattedDate: item.startDateFormattedDate,
                        endDateFormattedDate: item.endDateFormattedDate,
                        accountDownloadFileName: item.accountDownloadFileName,
                        accountUrl: item.accountUrl
                    });
                });
            };
            if (!data2[0].data && !data2[0].data.list) {
                if (data2[0].error && data2[0].error.length) {
                    message.warning(data2[0].error[0].message);
                };
            } else {
                data2[0].data.list.map(function (item) {
                    secondArr.push({
                        id: item.id,
                        uid: item.uid,
                        aid: item.aid,
                        activityNumber: item.activityNumber,
                        year: item.year,
                        startDate: item.startDate,
                        endDate: item.endDate,

                        internalAllCost:
                        item.internalLaborCost + item.internalDirectCost + item.internalDepreciationCost +
                        item.internalAmortizationCost + item.internalAmortizationCost + item.internalDesignCost +
                        item.internalEquipmentCost + item.internalOtherCost,

                        internalLaborCost: item.internalLaborCost,
                        internalDirectCost: item.internalDirectCost,
                        internalDepreciationCost: item.internalDepreciationCost,
                        internalAmortizationCost: item.internalAmortizationCost,
                        internalDesignCost: item.internalDesignCost,
                        internalEquipmentCost: item.internalEquipmentCost,
                        internalOtherCost: item.internalOtherCost,

                        externalTotalCost: item.externalTotalCost,
                        externalAbroadCost: item.externalAbroadCost,

                        allCost:
                        item.internalLaborCost + item.internalDirectCost + item.internalDepreciationCost +
                        item.internalAmortizationCost + item.internalAmortizationCost + item.internalDesignCost +
                        item.internalEquipmentCost + item.internalOtherCost + item.externalTotalCost,

                        enterpriseFiller: item.enterpriseFiller,
                        signDate: item.signDate,
                        signDateFormattedDate: item.signDateFormattedDate,

                        sortNumber: item.sortNumber,

                        startDateFormattedDate: item.startDateFormattedDate,
                        endDateFormattedDate: item.endDateFormattedDate,
                        accountDownloadFileName: item.accountDownloadFileName,
                        accountUrl: item.accountUrl
                    });
                });
            };
            if (!data3[0].data && !data3[0].data.list) {
                if (data3[0].error && data3[0].error.length) {
                    message.warning(data3[0].error[0].message);
                };
            } else {
                data3[0].data.list.map(function (item) {
                    thirdArr.push({
                        id: item.id,
                        uid: item.uid,
                        aid: item.aid,
                        activityNumber: item.activityNumber,
                        year: item.year,
                        startDate: item.startDate,
                        endDate: item.endDate,

                        internalAllCost:
                        item.internalLaborCost + item.internalDirectCost + item.internalDepreciationCost +
                        item.internalAmortizationCost + item.internalAmortizationCost + item.internalDesignCost +
                        item.internalEquipmentCost + item.internalOtherCost,

                        internalLaborCost: item.internalLaborCost,
                        internalDirectCost: item.internalDirectCost,
                        internalDepreciationCost: item.internalDepreciationCost,
                        internalAmortizationCost: item.internalAmortizationCost,
                        internalDesignCost: item.internalDesignCost,
                        internalEquipmentCost: item.internalEquipmentCost,
                        internalOtherCost: item.internalOtherCost,

                        externalTotalCost: item.externalTotalCost,
                        externalAbroadCost: item.externalAbroadCost,

                        allCost:
                        item.internalLaborCost + item.internalDirectCost + item.internalDepreciationCost +
                        item.internalAmortizationCost + item.internalAmortizationCost + item.internalDesignCost +
                        item.internalEquipmentCost + item.internalOtherCost + item.externalTotalCost,

                        enterpriseFiller: item.enterpriseFiller,
                        signDate: item.signDate,
                        signDateFormattedDate: item.signDateFormattedDate,

                        sortNumber: item.sortNumber,

                        startDateFormattedDate: item.startDateFormattedDate,
                        endDateFormattedDate: item.endDateFormattedDate,
                        accountDownloadFileName: item.accountDownloadFileName,
                        accountUrl: item.accountUrl
                    });
                });
            };
            this.setState({
                firstActivityData: firstArr,
                secondActivityData: secondArr,
                thirdActivityData: thirdArr
            });
        }.bind(this)).always(function () {
            this.loadTechProductData(uid);
        }.bind(this));
    },
    //第六
    loadTechProductData(uid) {
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/techProductList",
            data: {
                uid: uid,
                year: this.state.year
            }
        }).done(function (data) {
            let theArr = [];
            if (!data.data) {
                if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                }
            } else {
                data.data.list.map(function (item) {
                    theArr.push(
                        <li key={item.id}>
                            <p style={{ marginBottom: '10px', fontSize: '14px' }}><span>编号 </span> {item.serialNumber}</p>
                            <div className="all-item">
                                <span className="item-title">产品（服务）名称</span>
                                <span>{item.productName}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">技术领域</span>
                                <span>{getTechField(Number(item.technicalField1), item.technicalField2 ? Number(item.technicalField2) : null, item.technicalField3 ? Number(item.technicalField3) : null)}</span>
                            </div>
                            <div className="clearfix">
                                <div className="half-item">
                                    <span className="item-title">技术来源</span>
                                    <span>{getTechnicalSource(item.technicalSource)}</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">上年度销售收入</span>
                                    <span>{item.lastYearRevenue}</span>
                                    <span>万元</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">是否主要产品（服务）</span>
                                    <span>{item.mainProduct == 1 ? '是' : '否'}</span>
                                </div>
                                <div className="half-item">
                                    <span className="item-title">知识产权编号</span>
                                    <span>{item.intellectualPropertyNumber}</span>
                                </div>
                            </div>
                            <div className="all-item">
                                <span className="item-title">关键技术及主要技术指标</span>
                                <span>{item.keyTechnology}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">与同类产品（服务）的竞争优势</span>
                                <span>{item.competitiveEdge}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">知识产权获得情况及其对产品（服务）在技术上发挥的支持作用</span>
                                <span>{item.conditionEffect}</span>
                            </div>
                        </li>
                    )
                });
            };
            this.setState({
                techProductData: theArr
            });
        }.bind(this)).always(function () {
            this.loadAbilityData(uid);
        }.bind(this));
    },
    //第七
    loadAbilityData(uid) {
        $.ajax({
            method: "post",
            dataType: "json",
            url: globalConfig.context + "/api/admin/able",
            data: {
                uid: uid
            },
            success: function (data) {
                if (data.data) {
                    this.setState({
                        intellectRight: data.data.intellectRight,
                        scienceAchievement: data.data.scienceAchievement,
                        researchInnovation: data.data.researchInnovation,
                        personnel: data.data.personnel
                    });
                } else if (data.error && data.error.length) {
                    message.warning(data.error[0].message);
                };
            }.bind(this),
        }).always(function () {
            this.loadStandardData(uid);
        }.bind(this));
    },
    //第八
    loadStandardData(uid) {
        $.ajax({
            method: "post",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/standard",
            data: {
                uid: uid,
                year: this.state.year
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    }
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i + 1,
                            id: thisdata.id,
                            uid: thisdata.uid,
                            standardName: thisdata.standardName,
                            standardNumber: thisdata.standardNumber,
                            year: thisdata.year,
                            enclosureUrl: thisdata.enclosureUrl,
                            standardLevel: thisdata.standardLevel,
                            participateWay: thisdata.participateWay,
                            createTime: thisdata.createTime,
                            createTimeFormattedDate: thisdata.createTimeFormattedDate
                        });
                    };
                };
                this.setState({
                    standardTableData: theArr,
                });
            }.bind(this),
        });
    },
    componentWillMount() {
        if (window.location.search) {
            let theObj = getSearchUrl(window.location.search);
            this.loadInfoData(theObj.uid);
            this.loadHumanData(theObj.uid);
            this.loadLegalData(theObj.uid);
        };
    },
    render() {
        let theData = this.state;
        return (
            <Spin spinning={theData.loading}>
                <div id="Info-box">
                    <div className="Info-title">
                        {theData.unitName}高企认定材料
                    </div>
                    <div className="Info-content" >
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">年份</span>
                                <span>{theData.year}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">公司名字</span>
                                <span>{theData.unitName}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">通讯地址</span>
                                <span>{theData.postalAddress}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">法定代表人</span>
                                <span>{theData.legalPerson}</span>
                            </div>
                        </div>
                        <div className="content-title">
                            <span>企业注册登记表</span>
                        </div>
                        <p>法定代表人</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">电话</span>
                                <span>{theData.legalPersonTel}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">传真</span>
                                <span>{theData.legalPersonFax}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">E-mail</span>
                                <span>{theData.legalPersonEmail}</span>
                            </div>
                        </div>
                        <p>联系人</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">姓名</span>
                                <span>{theData.firstContacts}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">手机</span>
                                <span>{theData.firstMobile}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">电话</span>
                                <span>{theData.contactsFixedTel}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">传真</span>
                                <span>{theData.contactsFax}</span>
                            </div>
                        </div>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">通讯地址</span>
                                <span>{theData.postalAddress}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">邮政编码</span>
                                <span>{theData.postcode}</span>
                            </div>
                        </div>
                        <div className="all-item">
                            <span className="item-title">企业名称</span>
                            <span>{theData.unitName}</span>
                        </div>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">法定代表人</span>
                                <span>{theData.legalPerson}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">身份证号/护照号</span>
                                <span>{theData.legalPersonIdCard}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">注册时间</span>
                                <span>{theData.registrationTime}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">企业规模</span>
                                <span>{getScaleState(theData.enterpriseScale)}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">注册类型</span>
                                <span>{getCompanyType(Number(theData.registerType[0]), theData.registerType[1] ? Number(theData.registerType[1]) : null)}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">外资来源地</span>
                                <span>{theData.foreignInvestment}</span>
                            </div>
                        </div>
                        <div className="all-item">
                            <span className="item-title">技术领域</span>
                            <span>{getTechField(theData.field[0], theData.field[1], theData.field[2])}</span>
                        </div>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">组织机构代码/统一社会信用代码</span>
                                <span>{theData.orgCode}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">税务登记号/统一社会信用代码</span>
                                <span>{theData.ratepayCode}</span>
                            </div>
                        </div>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">主管税务机关</span>
                                <span>{
                                    (() => {
                                        if (theData.taxAuthority == '0') {
                                            return '国税';
                                        } else if (theData.taxAuthority == '1') {
                                            return '地税';
                                        };
                                    })()
                                }</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">所得税征收方式</span>
                                <span>{
                                    (() => {
                                        if (theData.ratepayMethod == '0') {
                                            return '查账征收';
                                        } else if (theData.ratepayMethod == '1') {
                                            return '核定征收';
                                        };
                                    })()
                                }</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">行政区域</span>
                                <span>{theData.address}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">注册资金</span>
                                <span>{theData.registeredCapital}</span>
                                <span>万元</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">是否高新区</span>
                                <span>{
                                    (() => {
                                        if (theData.highTechZone == '0') {
                                            return '否';
                                        } else if (theData.highTechZone == '1') {
                                            return '是';
                                        };
                                    })()
                                }</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">高新区名称</span>
                                <span>{theData.highTechName}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">是否上市</span>
                                <span>{
                                    (() => {
                                        if (theData.listed == '0') {
                                            return '否';
                                        } else if (theData.listed == '1') {
                                            return '是';
                                        };
                                    })()
                                }</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">上市类型</span>
                                <span>{
                                    (() => {
                                        if (theData.listedType == '0') {
                                            return '股票型上市公司';
                                        } else if (theData.listedType == '1') {
                                            return '债券型上市公司';
                                        };
                                    })()
                                }</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">上市时间</span>
                                <span>{theData.listedDate}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">股票代码</span>
                                <span>{theData.stockCode}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">所属行业</span>
                                <span>{getIndustryType(theData.industry)}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">是否引入风投</span>
                                <span>{
                                    (() => {
                                        if (theData.riskInvestment == '0') {
                                            return '否';
                                        } else if (theData.riskInvestment == '1') {
                                            return '是';
                                        };
                                    })()
                                }</span>
                            </div>
                            <p>自然人股权</p>
                            <Table className="company-table" style={{ padding: '10px 20px' }}
                                columns={this.state.humanColumns}
                                dataSource={this.state.humanTableData}
                                pagination={false} />
                            <p>法人股权</p>
                            <Table className="company-table" style={{ padding: '10px 20px' }}
                                columns={this.state.legalColumns}
                                dataSource={this.state.legalTableData}
                                pagination={false} />
                        </div>
                        <div className="content-title">
                            <span>高新企业认定申请</span>
                            <span>(主要情况)</span>
                        </div>
                        <div className="all-item">
                            <span className="item-title">技术领域</span>
                            <span>{getTechField(Number(theData.field[0]), theData.field[1] ? Number(theData.field[1]) : null, theData.field[2] ? Number(theData.field[2]) : null)}</span>
                        </div>
                        <p>获得知识产权数量（件）</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">Ⅰ 类</span>
                                <span>{theData.firstCatagory}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">Ⅱ 类</span>
                                <span>{theData.secondCatagory}</span>
                            </div>
                        </div>
                        <p>人力资源情况（人）</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">职工总数</span>
                                <span>{theData.firmTotal}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">科技人员数</span>
                                <span>{theData.techTotal}</span>
                            </div>
                        </div>
                        <p>近三年经营状况(万元)</p>
                        <Table
                            pagination={false}
                            dataSource={this.state.moneyTable}
                            columns={this.state.moneyColumns} />
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">净资产增长率</span>
                                <span>{(this.state.netAssetRate * 100).toFixed(2) + '%'}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">销售收入增长率</span>
                                <span>{(this.state.salesRevenueRate * 100).toFixed(2) + '%'}</span>
                            </div>
                        </div>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">近三年研究开发费用总额</span>
                                <span>{theData.researchCost}</span>
                                <span> 万元</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">在中国境内研发费用总和</span>
                                <span>{theData.territory}</span>
                                <span> 万元</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">基础研究投入费用总额</span>
                                <span>{theData.basicResearchCost}</span>
                                <span> 万元</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">近一年企业总收入</span>
                                <span>{theData.totalRevenue}</span>
                                <span> 万元</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">近一年高新技术产品收入</span>
                                <span>{theData.lastYearRevenue}</span>
                                <span> 万元</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title" style={{ width: 400 }}>申请认定前一年内是否发生过重大安全、重大质量或严重环境违法行为</span>
                                <span>{(() => {
                                    if (theData.accident == 0) {
                                        return '否';
                                    } else if (theData.accident == 1) {
                                        return '是';
                                    };
                                })()}</span>
                            </div>
                        </div>
                        <div className="content-title">
                            <span>高新企业认定申请</span>
                            <span>(知识产权汇总)</span>
                        </div>
                        <p>获得知识产权数量（件）（Ⅰ 类）</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">发明专利</span>
                                <span>{theData.inventionPatent}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">国防专利</span>
                                <span>{theData.defensePatent}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">植物新品种</span>
                                <span>{theData.newPlantCariety}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">国家级农作物品种</span>
                                <span>{theData.nationalCrop}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">国家新药</span>
                                <span>{theData.nationalDrug}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">国家一级中药保护品种</span>
                                <span>{theData.chineseMedicine}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">集成电路布图</span>
                                <span>{theData.circuitDesign}</span>
                            </div>
                        </div>
                        <p>获得知识产权数量（件）（Ⅱ 类）</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">实用新型</span>
                                <span>{theData.utilityPatent}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">软著</span>
                                <span>{theData.softwareWorks}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">外观设计</span>
                                <span>{theData.exteriorPatent}</span>
                            </div>
                        </div>
                        <Table
                            pagination={false}
                            dataSource={this.state.intellectualTableData}
                            columns={this.state.intellectualColumns} />
                        <div className="content-title">
                            <span>人力资源情况表</span>
                        </div>
                        <p>总体情况</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title" style={{ marginLeft: 150 }}>企业职工</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title" style={{ marginLeft: 150 }}>科技人员</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">总数</span>
                                <span>{theData.firmTotal}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techTotal}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">在职人员</span>
                                <span>{theData.firmInService}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techInService}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">兼职人员</span>
                                <span>{theData.firmPartTime}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techPartTime}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">临时聘用人员</span>
                                <span>{theData.firmTemporary}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techTemporary}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">外籍人员</span>
                                <span>{theData.firmForeign}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techForeign}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">留学归国人员</span>
                                <span>{theData.firmAbroad}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techAbroad}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">千人计划</span>
                                <span>{theData.firmCore}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title"></span>
                                <span>{theData.techCore}</span>
                            </div>
                        </div>
                        <p>全体人员结构</p>
                        <p>学历</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">博士</span>
                                <span>{theData.doctor}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">硕士</span>
                                <span>{theData.master}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">本科</span>
                                <span>{theData.undergraduate}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">大专及以下</span>
                                <span>{theData.college}</span>
                            </div>
                        </div>
                        <p>职称</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">高级职称</span>
                                <span>{theData.seniorTitle}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">中级职称</span>
                                <span>{theData.intermediateTitle}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">初级职称</span>
                                <span>{theData.juniorTitle}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">高级技工</span>
                                <span>{theData.seniorMechanic}</span>
                            </div>
                        </div>
                        <p>年龄</p>
                        <div className="clearfix">
                            <div className="half-item">
                                <span className="item-title">30及以下</span>
                                <span>{theData.belowThirty}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">31-40</span>
                                <span>{theData.thirtyoneToThirtyfour}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">41-50</span>
                                <span>{theData.fortyoneToFifty}</span>
                            </div>
                            <div className="half-item">
                                <span className="item-title">51及以上</span>
                                <span>{theData.aboveFifty}</span>
                            </div>
                        </div>
                        <div className="content-title">
                            <span>企业研究开发活动情况表</span>
                        </div>
                        <ul>{this.state.activityData}</ul>
                        <div className="content-title">
                            <span>企业年度研发费用结构明细表</span>
                        </div>
                        <p style={{ marginBottom: '10px', fontSize: '14px' }}>{this.state.year - 2} 年度 单位：万元</p>
                        <Table columns={this.state.activityCostColumns}
                            dataSource={this.state.firstActivityData}
                            pagination={false} />
                        <p style={{ marginBottom: '10px', fontSize: '14px' }}>{this.state.year - 1} 年度 单位：万元</p>
                        <Table columns={this.state.activityCostColumns}
                            dataSource={this.state.secondActivityData}
                            pagination={false} />
                        <p style={{ marginBottom: '10px', fontSize: '14px' }}>{this.state.year} 年度 单位：万元</p>
                        <Table columns={this.state.activityCostColumns}
                            dataSource={this.state.thirdActivityData}
                            pagination={false} />
                        <div className="content-title">
                            <span>上年度高新技术产品（服务）情况表</span>
                        </div>
                        <ul>{this.state.techProductData}</ul>
                        <div className="content-title">
                            <span>创业创新能力</span>
                        </div>
                        <div className="clearfix">
                            <div className="all-item">
                                <span className="item-title">知识产权对企业竞争力的作用</span>
                                <span>{theData.intellectRight}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">科技成果转化情况</span>
                                <span>{theData.scienceAchievement}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">研究开发与技术创新组织管理情况</span>
                                <span>{theData.researchInnovation}</span>
                            </div>
                            <div className="all-item">
                                <span className="item-title">管理与科技人员情况</span>
                                <span>{theData.personnel}</span>
                            </div>
                        </div>
                        <div className="content-title">
                            <span>企业参与国家标准或行业制定情况汇总表</span>
                        </div>
                        <Table columns={this.state.standardColumns}
                            dataSource={this.state.standardTableData}
                            pagination={false} />
                    </div>
                </div>
            </Spin>
        );
    }
});

export default highTechInfo;